@@ -9,7 +9,7 @@
 #
 package MooseX::AttributeShortcuts;
 {
-  $MooseX::AttributeShortcuts::VERSION = '0.010';
+  $MooseX::AttributeShortcuts::VERSION = '0.013';
 }
 
 # ABSTRACT: Shorthand for common attribute options
@@ -29,7 +29,7 @@ use Moose::Util::MetaRole;
 {
     package MooseX::AttributeShortcuts::Trait::Attribute;
 {
-  $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.010';
+  $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.013';
 }
     use namespace::autoclean;
     use MooseX::Role::Parameterized;
@@ -113,7 +113,9 @@ use Moose::Util::MetaRole;
         };
 
         # here we wrap _process_options() instead of the newer _process_is_option(),
-        # as that makes our life easier from a 1.x/2.x compatibility perspective.
+        # as that makes our life easier from a 1.x/2.x compatibility
+        # perspective -- and that we're potentially altering more than just
+        # the 'is' option at one time.
 
         before _process_options => $_process_options;
 
@@ -132,8 +134,8 @@ use Moose::Util::MetaRole;
     };
 }
 
-Moose::Exporter->setup_import_methods;
-my ($import) = Moose::Exporter->build_import_methods(
+my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
+    install => [ 'unimport' ],
     trait_aliases => [
         [ 'MooseX::AttributeShortcuts::Trait::Attribute' => 'Shortcuts' ],
     ],
@@ -153,11 +155,19 @@ sub import {
 }
 
 sub init_meta {
-    shift;
-    my %args = @_;
+    my ($class_name, %args) = @_;
     my $params = delete $args{role_params} || $role_params || undef;
     undef $role_params;
 
+    # Just in case we do ever start to get an $init_meta from ME
+    $init_meta->($class_name, %args)
+        if $init_meta;
+
+    # make sure we have a metaclass instance kicking around
+    my $for_class = $args{for_class};
+    die "Class $for_class has no metaclass!"
+        unless Class::MOP::class_of($for_class);
+
     # If we're given paramaters to pass on to construct a role with, we build
     # it out here rather than pass them on and allowing apply_metaroles() to
     # handle it, as there are Very Loud Warnings about how paramatized roles
@@ -173,12 +183,12 @@ sub init_meta {
         ;
 
     Moose::Util::MetaRole::apply_metaroles(
-        for             => $args{for_class},
+        for             => $for_class,
         class_metaroles => { attribute         => [ $role ] },
         role_metaroles  => { applied_attribute => [ $role ] },
     );
 
-    return $args{for_class}->meta;
+    return Class::MOP::class_of($for_class);
 }
 
 1;
@@ -189,13 +199,15 @@ sub init_meta {
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl
+
 =head1 NAME
 
 MooseX::AttributeShortcuts - Shorthand for common attribute options
 
 =head1 VERSION
 
-This document describes version 0.010 of MooseX::AttributeShortcuts - released April 06, 2012 as part of MooseX-AttributeShortcuts.
+This document describes version 0.013 of MooseX::AttributeShortcuts - released July 15, 2012 as part of MooseX-AttributeShortcuts.
 
 =head1 SYNOPSIS
 
